@@ -1,6 +1,7 @@
 // test.cc
 //
 //   Copyright (C) 2005, 2007-2010 Daniel Burrows
+//   Copyright (C) 2018 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -448,11 +449,11 @@ void run_test_file(istream &f, bool show_world)
 
 		      cout << " (ignored)" << endl;
 		    }
-		  catch(NoMoreTime)
+		  catch(const NoMoreTime&)
 		    {
 		      cout << "Ran out of steps (ignored)" << endl;
 		    }
-		  catch(NoMoreSolutions)
+		  catch(const NoMoreSolutions&)
 		    {
 		      cout << "Ran out of solutions (ignored)" << endl;
 		    }
@@ -506,11 +507,11 @@ void run_test_file(istream &f, bool show_world)
 			  cout << ">" << endl;
 			}
 		    }
-		  catch(NoMoreSolutions)
+		  catch(const NoMoreSolutions&)
 		    {
 		      cout << "Ran out of solutions (FAILED)" << endl;
 		    }
-		  catch(NoMoreTime)
+		  catch(const NoMoreTime&)
 		    {
 		      cout << "Ran out of time (FAILED)" << endl;
 		    }
