@@ -1,6 +1,7 @@
 // solution_screen.cc
 //
 //   Copyright (C) 2005, 2007-2009 Daniel Burrows
+//   Copyright (C) 2015-2016 Manuel A. Fernandez Montecelo
 //
 //   This program is free software; you can redistribute it and/or
 //   modify it under the terms of the GNU General Public License as
@@ -14,8 +15,8 @@
 //
 //   You should have received a copy of the GNU General Public License
 //   along with this program; see the file COPYING.  If not, write to
-//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-//   Boston, MA 02111-1307, USA.
+//   the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+//   Boston, MA 02110-1301, USA.
 
 #include "solution_screen.h"
 
@@ -147,8 +148,23 @@ public:
   {
     return my_label.c_str();
   }
-};
 
+  bool dispatch_key(const cw::config::key& k, cw::tree* owner) override
+  {
+    if (cw::config::global_bindings.key_matches(k, "SolutionActionReject") ||
+	cw::config::global_bindings.key_matches(k, "SolutionActionApprove"))
+      {
+	for (child_iterator i = get_children_begin(); i != get_children_end(); ++i)
+	  (*i)->dispatch_key(k, owner);
+
+	owner->line_down();
+
+	return true;
+      }
+    else
+      return cw::subtree_generic::dispatch_key(k, owner);
+  }
+};
 
 
 cw::subtree_generic *make_dep_solvers_tree(const aptitude_resolver_dep &d)
@@ -619,11 +635,6 @@ cw::widget_ref make_solution_screen()
   examiner->connect_menu_signals();
   create_menu_bindings(info_tree.unsafe_get_ref(), info_tree);
 
-
-  info_tree->connect_key("ShowHideDescription", &cw::config::global_bindings,
-			 sigc::mem_fun(info_tree.unsafe_get_ref(),
-				       &cw::widget::toggle_visible));
-
   l->set_bg_style(cw::get_style("Status"));
 
   rval->add_widget_opts(examiner,
@@ -644,6 +655,15 @@ cw::widget_ref make_solution_screen()
     resman->state_changed.connect(sigc::bind(sigc::ptr_fun(&maybe_remove_examiner),
 					     rval.weak_ref()));
 
+  // for #453853.  has to be done at the same time for all elements, or perhaps
+  // there should be a group of all the elements in the bottom half of the
+  // screen
+  rval->connect_key("ShowHideDescription", &cw::config::global_bindings,
+		    sigc::mem_fun(*info_tree.unsafe_get_ref(),
+				  &cw::widget::toggle_visible));
+  rval->connect_key("ShowHideDescription", &cw::config::global_bindings,
+		    sigc::mem_fun(*l.unsafe_get_ref(),
+				  &cw::widget::toggle_visible));
 
   l->show();
   examiner->show();
